==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/quarantine/folder.php <==
<?php

require_once ('inc/api/api.php');
require_once ('inc/folder.php');
require_once ('inc/quarantine/item.php');

class QuarantineFolder extends Folder
{
  public function __construct($name,$email)
  {
    $this->email = $email;
    $this->name  = $name;
    $this->folderID = 'Quarantine';

    switch($name)
    {
      case Q_FOLDER_NAME:
        $this->type = 'Q';
        $this->iAuthorized = 2;
      break;
      case B_FOLDER_NAME:
        $this->type = 'QL';
        $this->iAuthorized = 0;
      break;
      case W_FOLDER_NAME:
        $this->type = 'QL';
        $this->iAuthorized = 1;
      break;
    }
    $this->filter = " WHERE SndAuthorized='".$this->iAuthorized."' AND SndOwner = '".$this->email."'";

    $this->rights = 0;
  }
  
  public function getItems($aFilterTag)
  {
    //Initialize api object
    $api = new MerakAPI();
	

    $sort = '';
    $aFilterTag['orderby'] = str_replace('qdate asc','sndcreatedon asc,sndcreatedat asc',strtolower($aFilterTag['orderby']));
    $aFilterTag['orderby'] = str_replace('qdate desc','sndcreatedon desc,sndcreatedat desc',strtolower($aFilterTag['orderby']));
    if ($aFilterTag['orderby']) $sort.=' ORDER BY '.$aFilterTag['orderby'];
    if ($aFilterTag['sql']) $filter = ' '.$aFilterTag['sql'];
    
    if ($filter)
     $filter = " AND ".$filter;
    
    $this->lastFilter = $this->filter.$filter.$sort;
    $aList = $api->QuarantineList('',$this->lastFilter,$aFilterTag['limit']?$aFilterTag['limit']:0,$aFilterTag['offset']?$aFilterTag['offset']:0);  
    $aLines = Tools::explode_j(CRLF,$aList);

    //Create item objects
    foreach($aLines as $sLine)
    {
      $aLine = Tools::explode_j(";",$sLine);
      $return[$aLine[0].'#'.$aLine[4]] = new QuarantineItem($this,$aLine);
    }
    return $return;
  }
  
  public function getItem($id,$aItems = false)
  {
      $info = explode("#",$id);
      
      $api = new MerakAPI();
      $filter = " WHERE SndAuthorized='".$this->iAuthorized."' AND SndOwner = '".$info[1]."' AND SndEmail='".$info[0]."'";
      $aList = $api->QuarantineList('',$filter,0);  
      $aLines = Tools::explode_j(CRLF,$aList);
      $aItem = Tools::explode_j(";",$aLines[0]);

      if ($aItem)
        return new QuarantineItem($this,$aItem,true);    
  }  
  
    //Todo////////////////////////////////////////////////////////////
    public function deleteItems($oItems = false){
      foreach($oItems as $oItem)
        $oItem->delete();
    }
    
    
    //Theese methods do nothing for Quarantine items - so they are left blank
    //they are present because they are abstract functions
    public function moveItems($oFolder,$oItems = false){
    }
    
    public function copyItems($oFolder,$oItems = false){
    }
  /////////////////////////////////////////////////////////////////////////  
  //
  
  public function countItems($flags = 0,$positive = true,$filter = "")
  {
    // there are no flagged items in quarantine folder
		if ($flags)
    	return 0;
   
    $api = new MerakAPI;
    
    /*
     * If filter is not set , use the last one used
     * to retrieve items, without ordering commands
     */        
    if (!$filter){
      $filter = $this->lastFilter;
    }
    
    if ($pos = stripos($filter,'ORDER BY'))
      $filter = substr($filter,0,$pos);
    
    //Count items
    $count = $api->QuarantineList('',$filter."|count",0);

    //Fixme : API function returns {number};\r\n\r\n instead of {number}
    $count = trim(str_replace(";","",$count));

    return $count; 
  }
  public function whitelistItem($id, $aItems = false,$deliver = false)
  {
    $item = $this->getItem($id,$aItems);

    $item->whitelist(false,$deliver);
  }
  
  public function blacklistItem($id, $aItems = false)
  {
    $item = $this->getItem($id,$aItems);
    $item->blacklist();
  }  
  public function deliverItem($id, $aItems = false)
  {
    $item = $this->getItem($id,$aItems);
    $item->deliver();
  }
    
  public static function create($name,$email)
  {
    //return quarantine folder with specified name
    return new QuarantineFolder($name,$email = $_SESSION['EMAIL']);
  }
  
  public function delete()
  {}
  
  public function rename($newName)
  {}

  
  public function createItem($aItem)
  {    
    return QuarantineItem::create($this,$aItem);
  }
  
  public function sync()
  {}
  
}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/quarantine/folder.php <==
<?php

require_once ('inc/api/api.php');
require_once ('inc/folder.php');
require_once ('inc/quarantine/item.php');

class QuarantineFolder extends Folder
{
  public function __construct($name,$email)
  {
    $this->email = strtolower($email);
    $this->name  = $name;
    $this->folderID = 'Quarantine';

    switch($name)
    {
      case Q_FOLDER_NAME:
        $this->type = 'Q';
        $this->iAuthorized = 2;
      break;
      case B_FOLDER_NAME:
        $this->type = 'QL';
        $this->iAuthorized = 0;
      break;
      case W_FOLDER_NAME:
        $this->type = 'QL';
        $this->iAuthorized = 1;
      break;
    }
    $this->filter = " WHERE (SndAuthorized='".$this->iAuthorized."') AND (SndOwner = '".$this->email."')";

    $this->rights = 0;
  }
  
  public function getItems($aFilterTag = array())
  {
    //Initialize api object
    $api = new MerakAPI();

    //$sort = '';
    if ($aFilterTag['orderby']){
			$aFilterTag['orderby'] = str_replace('qdate asc','sndcreatedon asc,sndcreatedat asc',strtolower($aFilterTag['orderby']));
    	$aFilterTag['orderby'] = str_replace('qdate desc','sndcreatedon desc,sndcreatedat desc',strtolower($aFilterTag['orderby']));
		 	if($_SESSION['COLLATE_ENABLE']){
				$aFilterTag['orderby'] = Tools::collateOrderBy($aFilterTag['orderby']);
			}
		 $sort = ' ORDER BY '.$aFilterTag['orderby'];
    }

		if ($aFilterTag['sql']){
		 $filter = ' AND '.$aFilterTag['sql'];
		}

    $this->lastFilter = $this->filter.$filter.$sort;
    $aList = $api->QuarantineList('',$this->lastFilter,$aFilterTag['limit']?$aFilterTag['limit']:0,$aFilterTag['offset']?$aFilterTag['offset']:0);  
    //dmp($aList);die();
		$aLines = mb_split(CRLF,$aList);
		//Fix due to separator at the end
		unset($aLines[count($aLines)-1]);

    //Create item objects
    foreach($aLines as $sLine)
    {
      $aLine = mb_split(";",$sLine);
      $return[$aLine[0].'#'.$aLine[4]] = new QuarantineItem($this,$aLine);
    }
    
    return $return;
  }
  
  public function getItem($id,$aItems = false)
  {

      $id = base64_decode($id);
      $info = explode("#",$id);

      
      $api = new MerakAPI();
      $filter = " WHERE (SndAuthorized='".$this->iAuthorized."') AND (SndOwner = '".$info[1]."') AND (SndEmail='".$info[0]."')";
			$filter="||SndAuthorized=".urlencode($this->iAuthorized)."&SndOwner=".urlencode($info[1])."&SndEmail=".urlencode($info[0]);
      $aList = $api->QuarantineList('',$filter,0);  

      $aLines = mb_split(CRLF,$aList);
      $aItem = mb_split(";",$aLines[0]);

      if ($aItem)
        return new QuarantineItem($this,$aItem,true);    
  }  
  
    //Todo////////////////////////////////////////////////////////////
    public function deleteItems($oItems = false){
      if(!$oItems) $oItems = $this->getItems();
      foreach($oItems as $oItem)
        $oItem->delete();
    }
    
    //Theese methods do nothing for Quarantine items - so they are left blank
    //they are present because they are abstract functions
    public function moveItems($oFolder,$oItems = false){
    }
    
    public function copyItems($oFolder,$oItems = false){
    }
  /////////////////////////////////////////////////////////////////////////  
  //
  
  public function countItems($flags = 0,$positive = true,$filter = "")
  {
    // there are no flagged items in quarantine folder
		if ($flags)
    	return 0;
   
    $api = new MerakAPI;
    
    /*
     * If filter is not set , use the last one used
     * to retrieve items, without ordering commands
     */        
    if (!$filter){
      $filter = $this->lastFilter;
    }else{
      $filter= $this->lastFilter.$filter;
    }
    
    if ($pos = stripos($filter,'ORDER BY'))
      $filter = substr($filter,0,$pos);
    
    if($filter)
    //Count items
    $count = $api->QuarantineList('',$filter."|count",0);

    //Fixme : API function returns {number};\r\n\r\n instead of {number}
    $count = trim(str_replace(";","",$count));
		if(!$count){
			$count = 0;
		}
    return $count; 
  }
  public function whitelistItem($id, $aItems = false,$deliver = false)
  {
		$item = $this->getItem($id,$aItems);
    $item->whitelist(false,$deliver);
  }
  
  public function blacklistItem($id, $aItems = false)
  {
    $item = $this->getItem($id,$aItems);
    $item->blacklist();
  }  
  public function deliverItem($id, $aItems = false)
  {
    $item = $this->getItem($id,$aItems);
    $item->deliver();
  }
    
  public static function create($name,$email)
  {
    //return quarantine folder with specified name
    return new QuarantineFolder($name,$email = $_SESSION['EMAIL']);
  }
  
  public function delete()
  {}
  
  public function rename($newName)
  {}

  
  public function createItem($aItem)
  {    
    return QuarantineItem::create($this,$aItem);
  }
  
  public function sync()
  {}
  
  public function search($sPhrase,$aFilterTag)
  {
    return $this->getItems($aFilterTag);
  }
  
  
  
}
?>
